absorbing_centrality.absorbing_centrality_inversion — absorbing-centrality documentation

# absorbing_centrality.absorbing_centrality_inversion

`absorbing_centrality_inversion`(G, team, query=None, with_restarts=False, alpha=0.85)

  Compute the absorbing centrality of a team using a fast inversion with SuperLU solver.

  Parameters: | G (NetworkX graph) – The graph on which to compute the centrality. team (list) – The team of nodes, whose centrality to compute. query (list, optional) – The set of query nodes to use for the random walks. If None (default) or empty, the query set is equal to the set of all nodes in the graph. with_restarts (bool, optional) – If True, restarts the random surfer to the the query set (default is False). alpha (float, optional) – The probability of the random surfer to continue (default is 0.85).
  Returns: | score – The absorbing centrality score.
  Return type: | float

  Note

  Both team and query should use the original node names.